==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/AssigningShapeMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescription } from "./AssigningShapeMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningShapeMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningShapeMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningShapeMarkerStyleEventArgsDescriptionMetadata.c(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningShapeMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ad("AssigningShapeMarkerStyleEventArgs", () => new AssigningShapeMarkerStyleEventArgsDescription());
            a.ac("AssigningShapeMarkerStyleEventArgs", AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningShapeMarkerStyleEventArgsDescriptionMetadata, 'AssigningShapeMarkerStyleEventArgsDescriptionMetadata');
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningShapeMarkerStyleEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/AssigningShapeMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescription } from "./AssigningShapeMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningShapeMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningShapeMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningShapeMarkerStyleEventArgsDescriptionMetadata.c(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningShapeMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningShapeMarkerStyleEventArgs", () => new AssigningShapeMarkerStyleEventArgsDescription());
            a.ad("AssigningShapeMarkerStyleEventArgs", AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningShapeMarkerStyleEventArgsDescriptionMetadata, 'AssigningShapeMarkerStyleEventArgsDescriptionMetadata');
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningShapeMarkerStyleEventArgsDescriptionMetadata;
})();
